Title: Circular Statistics
LazyLoad: yes
Package: circular
Version: 0.5-2
Authors@R: c(
   person(given = "Ulric", family = "Lund", role = "aut",
          email = "ulund@calpoly.edu"),
   person(given = "Claudio", family = "Agostinelli", role = "aut",
          email = "claudio.agostinelli@unitn.it",
          comment = c(ORCID = "0000-0001-6702-4312")),
   person(given = "Hiroyoshi", family = "Arai", role = "ctb",
          email = "h_arai@aoni.waseda.jp"),
   person(given = "Alessando", family = "Gagliardi", role = "ctb",
          email = "gagliardi@stud.unive.it"),
   person(given = "Eduardo", family = "García-Portugués",
          role = c("ctb", "cre"), email = "edgarcia@est-econ.uc3m.es",
          comment = c(ORCID = "0000-0002-9224-4111")),
   person(given = "Dimitri", family = "Giunchi", role = "ctb",
          email = "dimitri.giunchi@unipi.it"),
   person(given = "Jean-Olivier", family = "Irisson", role = "ctb",
          email = "irisson@normalesup.org"),
   person(given = "Matthew", family = "Pocernich", role = "ctb",
          email = "pocernic@ucar.edu"),
   person(given = "Federico", family = "Rotolo", role = "ctb"))
Date: 2025-09-24
Depends: R (>= 3.0.0), stats
Imports: boot, mvtnorm
Description: Circular Statistics, from "Topics in circular Statistics" (2001) S. Rao Jammalamadaka and A. SenGupta, World Scientific.
License: GPL-2
NeedsCompilation: yes
Encoding: UTF-8
Packaged: 2025-09-24 14:28:59 UTC; Eduardo
Author: Ulric Lund [aut],
  Claudio Agostinelli [aut] (ORCID:
    <https://orcid.org/0000-0001-6702-4312>),
  Hiroyoshi Arai [ctb],
  Alessando Gagliardi [ctb],
  Eduardo García-Portugués [ctb, cre] (ORCID:
    <https://orcid.org/0000-0002-9224-4111>),
  Dimitri Giunchi [ctb],
  Jean-Olivier Irisson [ctb],
  Matthew Pocernich [ctb],
  Federico Rotolo [ctb]
Maintainer: Eduardo García-Portugués <edgarcia@est-econ.uc3m.es>
Repository: CRAN
Date/Publication: 2025-09-25 05:10:27 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 09:32:07 UTC; unix
Archs: circular.so.dSYM
