  Version 0.4-7 2023/08/19

  This is the circular package build over the R port of the CircStats package 
  by Ulric Lund <ulund@calpoly.edu> from "Topics in circular Statistics" (2001) S. Rao Jammalamadaka and A. SenGupta, World Scientific.

  See inst/NEWS for a partial list of changes.

Claudio Agostinelli <claudio@unive.it>
Ulric Lund <ulund@calpoly.edu>

Maintainer: Eduardo García-Portugués <edgarcia@est-econ.uc3m.es>
