\name{rao.table}
\title{Table for Rao's Spacing Test of Uniformity}
\alias{rao.table}

\description{Table for Rao's spacing test of uniformity}

\usage{data(rao.table)}

\author{Ulric Lund}

\seealso{
\code{\link{rao.spacing.test}}
}

\keyword{datasets}
